@@ -93,7 +93,7 @@ class AutoMode(callbacks.Plugin):
                 if not dismiss():
                     irc.queueMsg(msg)
                 else:
-                    self.log.info('Dismissing auto-mode for %s.' % msg.nick)
+                    self.log.info('Dismissing auto-mode for %s.', msg.args[2])
             delay = self.registryValue('delay', channel)
             if delay:
                 schedule.addEvent(f, time.time() + delay)
