@@ -77,10 +77,10 @@ class Filter(callbacks.Plugin):
                     msg = ircmsgs.IrcMsg(msg=msg, args=(msg.args[0], s))
         return msg
 
-    _filterCommands = ['jeffk', 'leet', 'rot13', 'hexlify', 'binary', 'lithp',
+    _filterCommands = ['jeffk', 'leet', 'rot13', 'hexlify', 'binary',
                        'scramble', 'morse', 'reverse', 'colorize', 'squish',
                        'supa1337', 'colorstrip', 'aol', 'rainbow', 'spellit',
-                       'hebrew', 'undup', 'gnu', 'shrink', 'azn', 'uniud']
+                       'hebrew', 'undup', 'gnu', 'shrink', 'uniud']
     @internationalizeDocstring
     def outfilter(self, irc, msg, args, channel, command):
         """[<channel>] [<command>]
@@ -227,30 +227,6 @@ class Filter(callbacks.Plugin):
         irc.reply(self._rot13_encoder(text)[0])
     rot13 = wrap(rot13, ['text'])
 
-    @internationalizeDocstring
-    def lithp(self, irc, msg, args, text):
-        """<text>
-
-        Returns the lisping version of <text>
-        """
-        text = text.replace('sh', 'th')
-        text = text.replace('SH', 'TH')
-        text = text.replace('Sh', 'Th')
-        text = text.replace('ss', 'th')
-        text = text.replace('SS', 'TH')
-        text = text.replace('s', 'th')
-        text = text.replace('z', 'th')
-        text = text.replace('S', 'Th')
-        text = text.replace('Z', 'Th')
-        text = text.replace('x', 'kth')
-        text = text.replace('X', 'KTH')
-        text = text.replace('cce', 'kth')
-        text = text.replace('CCE', 'KTH')
-        text = text.replace('tion', 'thion')
-        text = text.replace('TION', 'THION')
-        irc.reply(text)
-    lithp = wrap(lithp, ['text'])
-
     _leettrans = utils.str.MultipleReplacer(dict(list(zip('oOaAeElBTiIts',
                                                      '004433187!1+5'))))
     _leetres = [(re.compile(r'\b(?:(?:[yY][o0O][oO0uU])|u)\b'), 'j00'),
@@ -672,16 +648,6 @@ class Filter(callbacks.Plugin):
         irc.reply(text)
     shrink = wrap(shrink, ['text'])
 
-    _azn_trans = utils.str.MultipleReplacer(dict(list(zip('rlRL', 'lrLR'))))
-    @internationalizeDocstring
-    def azn(self, irc, msg, args, text):
-        """<text>
-
-        Returns <text> with the l's made into r's and r's made into l's.
-        """
-        text = self._azn_trans(text)
-        irc.reply(text)
-    azn = wrap(azn, ['text'])
 
     # TODO: 2,4,;
     # XXX suckiest: B,K,P,Q,T
