@@ -454,7 +454,10 @@ class User(callbacks.Plugin):
                 if len(keyids) == 0:
                     raise ValueError
                 for keyid in keyids:
-                    user.gpgkeys.remove(keyid)
+                    try:
+                        user.gpgkeys.remove(keyid)
+                    except ValueError:
+                        user.gpgkeys.remove('0x' + keyid)
                 gpg.keyring.delete_keys(fingerprint)
                 irc.replySuccess()
             except ValueError:
@@ -522,7 +525,12 @@ class User(callbacks.Plugin):
                 found = False
                 for (id, user) in ircdb.users.items():
                     if keyid in [x[-len(keyid):] for x in user.gpgkeys]:
-                        user.addAuth(msg.prefix)
+                        try:
+                            user.addAuth(msg.prefix)
+                        except ValueError:
+                            irc.error(_('Your secure flag is true and your '
+                                      'hostmask doesn\'t match any of your '
+                                      'known hostmasks.'), Raise=True)
                         ircdb.users.setUser(user, flush=False)
                         irc.reply(_('You are now authenticated as %s.') %
                                 user.name)
@@ -603,7 +611,7 @@ class User(callbacks.Plugin):
             user = ircdb.users.getUser(msg.prefix)
             irc.reply(user.name)
         except KeyError:
-            irc.reply(_('I don\'t recognize you. You can messsage me either of these two commands: "user identify <username> <password>" to log in or "user register <username> <password>" to register.'))
+            irc.reply(_('I don\'t recognize you. You can message me either of these two commands: "user identify <username> <password>" to log in or "user register <username> <password>" to register.'))
     whoami = wrap(whoami)
 
     @internationalizeDocstring
